from ..game_data.text_data import eb_text_table
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    from .. import EarthBoundWorld

random_flavors = [
    "Mint flavor",
    "Strawberry flavor",
    "Banana flavor",
    "Peanut flavor",
    "Crystal flavor",
    "Cherry flavor",
    "Grape flavor",
    "Blueberry flavor",
    "Handheld flavor",
    "Rotten flavor",
    "Golden flavor",
    "Herbal flavor",
    "Cherry Cola flavor",
    "Salt and Pepper flavor",
    "Pizza flavor",
    "Cotton Candy flavor",
    "Potato flavor",
    "Lemon-lime flavor",
    "Raisin flavor",
    "Chocolate flavor",
    "Ginger Ale flavor",
    "Orange Cream flavor",
    "Choco Cream flavor",
    "Doomed flavor",
    "Farm flavor",
    "Negative flavor",
    "Astral flavor",
    "Sunflower flavor",
    "Encore flavor",
    "Experimental flavor",
    "Blueblue flavor",
    "Deeppurple flavor",
    "Rivalry flavor",
    "Sugar flavor",
    "Faith flavor",
    "Wisdom flavor",
    "Hamburger flavor",
    "Spearmint flavor",
    "Tuna flavor",
    "Milk flavor",
    "Peppermint flavor",
    "Toothpaste flavor",
    "Barbecue flavor",
    "Lavender flavor",
    "Apple flavor",
    "Peach flavor",
    "Bubblegum flavor",
    "Orange flavor",
    "Toilet flavor",
    "Lemonade flavor",
    "Garlic flavor"
]


flavor_data = {
    "Cherry flavor": [0x00, 0x00, 0xde, 0x5f, 0x9c, 0x2d, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0xf2, 0x41, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbf, 0x57, 0xda, 0x28, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0xba, 0x49, 0x3f, 0x56, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0xde, 0x5f, 0x44, 0x06, 0x44, 0x2a, 0x80, 0x3b, 0x7f, 0x67, 0xda, 0x28, 0xaa, 0x28],

    "Grape flavor": [0x00, 0x00, 0xde, 0x5f, 0x9c, 0x2d, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0x2f, 0x4a, 0x25, 0x14,
                     0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbf, 0x57, 0x13, 0x4c, 0x25, 0x14,
                     0x80, 0x3b, 0xde, 0x5f, 0xc8, 0x40, 0x2f, 0x55, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                     0x80, 0x3b, 0xde, 0x5f, 0x44, 0x30, 0x44, 0x30, 0x80, 0x3b, 0x5f, 0x63, 0xb2, 0x69, 0xc7, 0x28],

    "Blueberry flavor": [0x00, 0x00, 0xde, 0x5f, 0x9c, 0x2d, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0x4d, 0x4a, 0x25, 0x14,
                         0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbf, 0x57, 0x86, 0x7d, 0x25, 0x14,
                         0x80, 0x3b, 0xde, 0x5f, 0x04, 0x41, 0x04, 0x56, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                         0x80, 0x3b, 0xbd, 0x77, 0x63, 0x30, 0x63, 0x30, 0x80, 0x3b, 0xb9, 0x77, 0xa4, 0x55, 0xc4, 0x28],

    "Handheld flavor": [0x00, 0x00, 0xff, 0x7f, 0xab, 0x29, 0xa3, 0x0c, 0x80, 0x3b, 0xff, 0x77, 0x6f, 0x36, 0xa3, 0x0c,
                        0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xd4, 0x4e, 0xeb, 0x25, 0xa3, 0x0c,
                        0x80, 0x3b, 0xff, 0x77, 0xec, 0x2d, 0x57, 0x5f, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                        0x80, 0x3b, 0xff, 0x77, 0x89, 0x25, 0xa3, 0x0c, 0x80, 0x3b, 0x50, 0x3e, 0xab, 0x29, 0x47, 0x1d],

    "Rotten flavor": [0x00, 0x00, 0xbf, 0x57, 0x9c, 0x2d, 0x25, 0x14, 0x80, 0x3b, 0xa8, 0x42, 0x84, 0x31, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbe, 0x57, 0x4f, 0x79, 0x25, 0x14,
                      0x80, 0x3b, 0x16, 0x56, 0x84, 0x18, 0xc7, 0x24, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0x16, 0x56, 0x10, 0x20, 0x10, 0x20, 0x80, 0x3b, 0x18, 0x42, 0x8a, 0x30, 0x44, 0x20],

    "Golden flavor": [0x00, 0x00, 0xbf, 0x57, 0x9c, 0x2d, 0x25, 0x14, 0x80, 0x3b, 0xbf, 0x4b, 0x18, 0x22, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbe, 0x57, 0x4f, 0x79, 0x25, 0x14,
                      0x80, 0x3b, 0xff, 0x6f, 0x50, 0x08, 0x58, 0x11, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0xff, 0x6f, 0x9f, 0x30, 0x9f, 0x30, 0x80, 0x3b, 0xff, 0x63, 0xfd, 0x2a, 0xaa, 0x1c],

    "Herbal flavor": [0x00, 0x00, 0xbf, 0x57, 0x9c, 0x2d, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0x6d, 0x46, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbe, 0x57, 0x4f, 0x79, 0x25, 0x14,
                      0x80, 0x3b, 0xdd, 0x6f, 0x86, 0x21, 0x69, 0x22, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0xdd, 0x6f, 0x48, 0x6e, 0x48, 0x6e, 0x80, 0x3b, 0xba, 0x63, 0xaa, 0x2a, 0x06, 0x29],

    "Cherry Cola flavor": [0x00, 0x00, 0xde, 0x5f, 0x9c, 0x2d, 0x08, 0x14, 0x80, 0x3b, 0x9f, 0x2d, 0x76, 0x24, 0x08, 0x14,
                           0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbf, 0x57, 0x9f, 0x2d, 0x08, 0x14,
                           0x80, 0x3b, 0xff, 0x5e, 0x73, 0x04, 0x89, 0x00, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                           0x80, 0x3b, 0xff, 0x5e, 0x89, 0x00, 0x89, 0x00, 0x80, 0x3b, 0x9f, 0x2d, 0x89, 0x00, 0x08, 0x14],

    "Salt and Pepper flavor": [0x00, 0x00, 0xff, 0x7f, 0x39, 0x67, 0xa5, 0x20, 0x80, 0x3b, 0xff, 0x77, 0x0d, 0x4e, 0xa5, 0x20,
                               0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0x51, 0x4e, 0xdd, 0x7f, 0xa5, 0x20,
                               0x00, 0x00, 0xff, 0x7f, 0x31, 0x52, 0x59, 0x77, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                               0x80, 0x3b, 0xff, 0x7f, 0x00, 0x00, 0x40, 0x10, 0x80, 0x3b, 0x30, 0x46, 0x6a, 0x2d, 0x83, 0x14],

    "Pizza flavor": [0x00, 0x00, 0xde, 0x5f, 0x39, 0x67, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0x1e, 0x0e, 0x25, 0x14,
                     0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                     0x00, 0x00, 0x7f, 0x5b, 0xb5, 0x10, 0xbe, 0x2a, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                     0x80, 0x3b, 0xde, 0x5f, 0x52, 0x79, 0x52, 0x79, 0x80, 0x3b, 0x7f, 0x5b, 0xbe, 0x2a, 0xc7, 0x28],

    "Cotton Candy flavor": [0x00, 0x00, 0xde, 0x5f, 0x3f, 0x7f, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0x6a, 0x56, 0x25, 0x14,
                            0x80, 0x3b, 0xde, 0x5f, 0x1b, 0x1c, 0x1b, 0x1c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                            0x00, 0x00, 0x9f, 0x73, 0xf1, 0x62, 0xfe, 0x3d, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                            0x80, 0x3b, 0xde, 0x5f, 0x52, 0x79, 0x52, 0x79, 0x80, 0x3b, 0x9f, 0x73, 0xfe, 0x3d, 0xc7, 0x28],

    "Crystal flavor": [0x00, 0x00, 0xde, 0x5f, 0x8c, 0x31, 0x02, 0x28, 0x80, 0x3b, 0xff, 0x77, 0x6d, 0x3a, 0x02, 0x28,
                       0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x02, 0x28,
                       0x80, 0x3b, 0xff, 0x7f, 0x00, 0x40, 0x00, 0x40, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                       0x80, 0x3b, 0xde, 0x5f, 0x52, 0x79, 0x52, 0x79, 0x80, 0x3b, 0xad, 0x35, 0x5a, 0x6b, 0xc6, 0x18],

    "Potato flavor": [0x00, 0x00, 0xde, 0x5f, 0x3f, 0x67, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x7b, 0x55, 0x4e, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                      0x80, 0x3b, 0x48, 0x10, 0x57, 0x4a, 0x1b, 0x57, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0x48, 0x10, 0x18, 0x19, 0x18, 0x15, 0x80, 0x3b, 0xff, 0x73, 0x1c, 0x57, 0xca, 0x28],

    "Lemon-lime flavor": [0x00, 0x00, 0xde, 0x5f, 0x3f, 0x67, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x5b, 0x9e, 0x17, 0x25, 0x14,
                          0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x25, 0x0a, 0x25, 0x14,
                          0x80, 0x3b, 0x25, 0x0a, 0xfd, 0x37, 0xaf, 0x17, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                          0x80, 0x3b, 0x25, 0x0a, 0xcf, 0x17, 0xcf, 0x17, 0x80, 0x3b, 0x25, 0x0a, 0xcf, 0x17, 0xc7, 0x28],

    "Raisin flavor": [0x00, 0x00, 0xde, 0x5f, 0x3f, 0x67, 0x25, 0x14, 0x80, 0x3b, 0x94, 0x61, 0x0a, 0x41, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                      0x80, 0x3b, 0xfb, 0x6e, 0x44, 0x18, 0xc7, 0x20, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0xfb, 0x6e, 0x95, 0x20, 0x95, 0x20, 0x80, 0x3b, 0xfb, 0x6e, 0x0c, 0x55, 0x84, 0x20],

    "Chocolate flavor": [0x00, 0x00, 0xde, 0x5f, 0x8e, 0x09, 0x43, 0x0c, 0x80, 0x3b, 0x37, 0x3a, 0x10, 0x21, 0x43, 0x0c,
                         0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x43, 0x0c,
                         0x80, 0x3b, 0x3c, 0x57, 0x25, 0x0c, 0x8a, 0x10, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                         0x80, 0x3b, 0x3c, 0x57, 0x38, 0x32, 0x38, 0x32, 0x80, 0x3b, 0xd2, 0x31, 0x88, 0x14, 0x43, 0x0c],

    "Ginger Ale flavor": [0x00, 0x00, 0xde, 0x5f, 0x8e, 0x09, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x6f, 0x6d, 0x3a, 0x25, 0x14,
                          0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xbf, 0x57, 0xed, 0x12, 0x25, 0x14,
                          0x80, 0x3b, 0x9f, 0x57, 0xed, 0x12, 0x80, 0x11, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                          0x80, 0x3b, 0x9f, 0x57, 0xb6, 0x09, 0xb6, 0x09, 0x80, 0x3b, 0x9f, 0x57, 0x80, 0x11, 0xe0, 0x00],

    "Orange Cream flavor": [0x00, 0x00, 0xde, 0x5f, 0x8e, 0x09, 0x25, 0x14, 0x80, 0x3b, 0x9f, 0x6b, 0x9f, 0x2a, 0x25, 0x14,
                            0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xbf, 0x57, 0x5f, 0x12, 0x25, 0x14,
                            0x80, 0x3b, 0xda, 0x09, 0x3f, 0x53, 0x5f, 0x12, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                            0x00, 0x00, 0xda, 0x09, 0x3f, 0x53, 0x3f, 0x53, 0x80, 0x3b, 0x9f, 0x6b, 0x5f, 0x12, 0x89, 0x00],

    "Amethyst flavor": [0x00, 0x00, 0xde, 0x5f, 0x8e, 0x09, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0xf2, 0x41, 0x25, 0x14,
                        0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xdf, 0x67, 0x3c, 0x78, 0x25, 0x14,
                        0x80, 0x3b, 0xde, 0x73, 0xaf, 0x40, 0x3c, 0x78, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                        0x00, 0x00, 0xde, 0x73, 0x1f, 0x68, 0x1f, 0x68, 0x80, 0x3b, 0x7f, 0x67, 0x3c, 0x78, 0xaf, 0x40],

    "Choco Cream flavor": [0x00, 0x00, 0xde, 0x5f, 0x8e, 0x09, 0x25, 0x14, 0x28, 0x21, 0xee, 0x39, 0x08, 0x25, 0x25, 0x14,
                           0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xdf, 0x67, 0x4f, 0x79, 0x25, 0x14,
                           0x80, 0x3b, 0xc8, 0x28, 0x18, 0x6b, 0xdf, 0x77, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                           0x00, 0x00, 0xc8, 0x28, 0x70, 0x4b, 0x70, 0x4b, 0x80, 0x3b, 0xdf, 0x7b, 0xf8, 0x5e, 0x06, 0x29],

    "Doomed flavor": [0x00, 0x00, 0x1f, 0x00, 0x8e, 0x09, 0x25, 0x14, 0x00, 0x00, 0x19, 0x00, 0x0a, 0x00, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xdf, 0x67, 0x1f, 0x00, 0x25, 0x14,
                      0x80, 0x3b, 0x1f, 0x00, 0x4a, 0x29, 0x2a, 0x29, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x00, 0x00, 0x19, 0x18, 0x00, 0x00, 0x00, 0x00, 0x80, 0x3b, 0xef, 0x3d, 0x6b, 0x2d, 0x84, 0x10],

    "Farm flavor": [0x00, 0x00, 0xbd, 0x32, 0x8e, 0x09, 0x4a, 0x04, 0x00, 0x00, 0xde, 0x32, 0x1a, 0x1e, 0x4a, 0x04,
                    0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xdf, 0x67, 0x7f, 0x02, 0x4a, 0x04,
                    0x80, 0x3b, 0x4a, 0x00, 0x1f, 0x3b, 0x9d, 0x2e, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                    0x00, 0x00, 0x5f, 0x43, 0xbb, 0x3a, 0xbb, 0x3a, 0x80, 0x3b, 0x5e, 0x02, 0x36, 0x01, 0xf0, 0x04],

    "Inverted flavor": [0x00, 0x00, 0x00, 0x00, 0x8e, 0x09, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0x7f,
                        0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xff, 0x7f, 0x00, 0x00, 0xff, 0x7f,
                        0x80, 0x3b, 0x00, 0x00, 0xff, 0x7f, 0xff, 0x7f, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                        0x00, 0x00, 0x00, 0x00, 0xff, 0x7f, 0xff, 0x7f, 0x80, 0x3b, 0xff, 0x7f, 0xff, 0x7f, 0x00, 0x00],

    "Negative flavor": [0x00, 0x00, 0xff, 0x7f, 0x8e, 0x09, 0x00, 0x00, 0x00, 0x00, 0xff, 0x7f, 0xff, 0x7f, 0x00, 0x00,
                        0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0x00, 0x00, 0xff, 0x7f, 0x00, 0x00,
                        0x80, 0x3b, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                        0x00, 0x00, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00, 0x80, 0x3b, 0xff, 0x7f, 0x00, 0x00, 0x00, 0x00],

    "Astral flavor": [0x00, 0x00, 0x5b, 0x7f, 0x8e, 0x09, 0x21, 0x14, 0x00, 0x00, 0xff, 0x77, 0xed, 0x58, 0x21, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xfa, 0x7a, 0x92, 0x6c, 0x21, 0x14,
                      0x80, 0x3b, 0x5b, 0x7f, 0xed, 0x58, 0x87, 0x38, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x00, 0x00, 0x5b, 0x7f, 0xd3, 0x79, 0xd3, 0x79, 0x80, 0x3b, 0xfa, 0x7a, 0xa8, 0x38, 0x21, 0x1c],

    "Sunflower flavor": [0x00, 0x00, 0xdf, 0x63, 0x8e, 0x09, 0x65, 0x04, 0x00, 0x00, 0xbf, 0x57, 0xb3, 0x15, 0x65, 0x04,
                         0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xdf, 0x57, 0x9a, 0x12, 0x65, 0x04,
                         0x80, 0x3b, 0xdf, 0x63, 0x1c, 0x37, 0xdf, 0x37, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                         0x00, 0x00, 0xdf, 0x63, 0x70, 0x09, 0x70, 0x09, 0x80, 0x3b, 0xdf, 0x57, 0xdb, 0x26, 0x4e, 0x15],

    "Encore flavor": [0x00, 0x00, 0xff, 0x7f, 0x73, 0x4e, 0x84, 0x1c, 0x00, 0x00, 0xbd, 0x7f, 0x8b, 0x45, 0x84, 0x1c,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0x5f, 0x6f, 0x4a, 0x59, 0x84, 0x1c,
                      0x80, 0x3b, 0xff, 0x7f, 0x12, 0x7e, 0xbf, 0x27, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x00, 0x00, 0xff, 0x7f, 0x7f, 0x3c, 0x7f, 0x3c, 0x80, 0x3b, 0x5f, 0x6f, 0x7e, 0x40, 0x31, 0x1c],

    "Experimental flavor": [0x00, 0x00, 0x9e, 0x5f, 0x80, 0x65, 0x64, 0x08, 0x00, 0x00, 0xff, 0x77, 0x2c, 0x15, 0x64, 0x08,
                            0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0x35, 0x7f, 0x0a, 0x7a, 0x64, 0x08,
                            0x80, 0x3b, 0x9e, 0x5f, 0x50, 0x19, 0xec, 0x10, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                            0x00, 0x00, 0x9e, 0x5f, 0x4a, 0x7a, 0x4a, 0x7a, 0x80, 0x3b, 0x35, 0x7f, 0x47, 0x76, 0xe4, 0x38],

    "Blueblue flavor": [0x00, 0x00, 0x97, 0x7b, 0x00, 0x4c, 0x21, 0x14, 0x00, 0x00, 0x0c, 0x66, 0xc3, 0x28, 0x21, 0x14,
                        0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0x08, 0x6e, 0x24, 0x55, 0x21, 0x14,
                        0x80, 0x3b, 0x97, 0x7b, 0x82, 0x20, 0x62, 0x45, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                        0x00, 0x00, 0x97, 0x7b, 0x27, 0x71, 0x27, 0x71, 0x80, 0x3b, 0x08, 0x6e, 0x43, 0x49, 0x82, 0x1c],

    "Deeppurple flavor": [0x00, 0x00, 0xfb, 0x7a, 0x13, 0x4c, 0x25, 0x10, 0x00, 0x00, 0x16, 0x69, 0x8b, 0x40, 0x25, 0x10,
                          0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0xeb, 0x33, 0x73, 0x70, 0x2b, 0x44, 0x21, 0x14,
                          0x80, 0x3b, 0xfb, 0x7a, 0x29, 0x30, 0x4c, 0x44, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                          0x00, 0x00, 0xfb, 0x7a, 0x17, 0x6c, 0x17, 0x6c, 0x80, 0x3b, 0x73, 0x70, 0x6c, 0x48, 0x45, 0x1c],

    "Rivalry flavor": [0x00, 0x00, 0xfe, 0x5e, 0x0c, 0x7c, 0x25, 0x04, 0x00, 0x00, 0x5e, 0x1d, 0x70, 0x0c, 0x25, 0x04,
                       0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0xeb, 0x33, 0x15, 0x7f, 0xb3, 0x14, 0x25, 0x04,
                       0x80, 0x3b, 0xfe, 0x5e, 0xea, 0x59, 0x6d, 0x6a, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                       0x00, 0x00, 0xfe, 0x5e, 0xc0, 0x6d, 0xc0, 0x6d, 0x80, 0x3b, 0x15, 0x7f, 0x86, 0x55, 0xe4, 0x34],

    "Sugar flavor": [0x00, 0x00, 0x9c, 0x73, 0x39, 0x67, 0x63, 0x0c, 0x00, 0x00, 0x9c, 0x73, 0x52, 0x4a, 0x63, 0x0c,
                     0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0xeb, 0x33, 0x9c, 0x73, 0x4a, 0x29, 0x63, 0x0c,
                     0x80, 0x3b, 0x42, 0x08, 0xff, 0x7f, 0x39, 0x67, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                     0x00, 0x00, 0x9c, 0x73, 0x42, 0x08, 0x42, 0x08, 0xe0, 0x33, 0x9c, 0x73, 0xf7, 0x5e, 0x8c, 0x31],

    "Faith flavor": [0x00, 0x00, 0xfe, 0x77, 0x3f, 0x67, 0x45, 0x10, 0x00, 0x00, 0xbe, 0x63, 0x7b, 0x3e, 0x45, 0x10,
                     0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0xeb, 0x33, 0x5d, 0x43, 0x9f, 0x40, 0x45, 0x10,
                     0xec, 0x33, 0xfe, 0x77, 0xdd, 0x72, 0x3c, 0x66, 0x80, 0x3b, 0x4a, 0x29, 0x08, 0x21, 0xa5, 0x14,
                     0x00, 0x00, 0xdf, 0x77, 0x1d, 0x28, 0x1d, 0x28, 0xe0, 0x33, 0xdf, 0x6a, 0x9f, 0x51, 0x4e, 0x1c],

    "Wisdom flavor": [0x00, 0x00, 0xfe, 0x77, 0x80, 0x19, 0x40, 0x04, 0x00, 0x00, 0xb3, 0x46, 0x89, 0x1d, 0x40, 0x04,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0xeb, 0x33, 0xb3, 0x46, 0x20, 0x1d, 0x40, 0x04,
                      0xec, 0x33, 0xc1, 0x10, 0x24, 0x2e, 0x80, 0x25, 0x80, 0x3b, 0x4a, 0x29, 0x08, 0x21, 0xa5, 0x14,
                      0x00, 0x00, 0xfe, 0x77, 0x29, 0x25, 0x29, 0x25, 0xe0, 0x33, 0xcc, 0x46, 0x24, 0x2e, 0x20, 0x11],
    
    "Hamburger flavor": [0x00, 0x00, 0xbf, 0x6b, 0x3f, 0x67, 0x25, 0x14, 0x80, 0x3b, 0xdc, 0x36, 0xd1, 0x19, 0x25, 0x14,
                         0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x6b, 0xfd, 0x1a, 0x25, 0x14,
                         0x80, 0x3b, 0x00, 0x00, 0x54, 0x08, 0x9f, 0x2f, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                         0x80, 0x3b, 0xff, 0x77, 0x0d, 0x1b, 0x0d, 0x1b, 0x80, 0x3b, 0x50, 0x11, 0x16, 0x2e, 0x85, 0x10],

    "Spearmint flavor": [0x00, 0x00, 0xde, 0x5f, 0x07, 0x1f, 0x25, 0x14, 0x00, 0x00, 0xff, 0x77, 0x8f, 0x3e, 0x25, 0x14,
                         0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xbf, 0x57, 0x4e, 0x7d, 0x25, 0x14,
                         0x80, 0x3b, 0xde, 0x5f, 0xa6, 0x1e, 0x6e, 0x3f, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                         0x00, 0x00, 0xde, 0x5f, 0x50, 0x71, 0x50, 0x71, 0x80, 0x3b, 0xf9, 0x67, 0x4d, 0x3b, 0x88, 0x24],

    "Tuna flavor": [0x00, 0x00, 0xde, 0x5f, 0x07, 0x1f, 0x25, 0x14, 0x00, 0x00, 0xff, 0x77, 0x93, 0x42, 0x25, 0x14,
                    0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xbf, 0x57, 0x4e, 0x7d, 0x25, 0x14,
                    0x80, 0x3b, 0xde, 0x5f, 0x58, 0x29, 0x14, 0x21, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                    0x00, 0x00, 0xde, 0x5f, 0x52, 0x79, 0x52, 0x79, 0x80, 0x3b, 0x1f, 0x63, 0x9b, 0x31, 0x68, 0x14],

    "Milk flavor": [0x00, 0x00, 0xde, 0x5f, 0x07, 0x1f, 0x25, 0x14, 0x00, 0x00, 0xff, 0x77, 0x73, 0x4e, 0x25, 0x14,
                    0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xbf, 0x57, 0x4e, 0x7d, 0x25, 0x14,
                    0x80, 0x3b, 0x42, 0x08, 0xb5, 0x4e, 0x7b, 0x67, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                    0x00, 0x00, 0xde, 0x5f, 0x52, 0x79, 0x52, 0x79, 0x80, 0x3b, 0xbd, 0x77, 0xf7, 0x5e, 0xc7, 0x28],

    "Peppermint flavor": [0x00, 0x00, 0xfe, 0x73, 0xde, 0x5f, 0x25, 0x14, 0x45, 0x1a, 0x7f, 0x4e, 0xd9, 0x00, 0x25, 0x14,
                          0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xff, 0x7f, 0xd9, 0x00, 0x25, 0x14,
                          0x80, 0x3b, 0x42, 0x08, 0xff, 0x7f, 0xd9, 0x00, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                          0x00, 0x00, 0xff, 0x7f, 0x13, 0x18, 0x13, 0x00, 0x80, 0x3b, 0xff, 0x7f, 0xdf, 0x18, 0x68, 0x14],
    
    "Toothpaste flavor": [0x00, 0x00, 0xfe, 0x73, 0xde, 0x5f, 0x25, 0x14, 0x45, 0x1a, 0xf3, 0x7f, 0x20, 0x7f, 0x25, 0x14,
                          0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xff, 0x7f, 0x20, 0x7f, 0x25, 0x14,
                          0x80, 0x3b, 0x42, 0x08, 0xec, 0x7f, 0x26, 0x7f, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                          0x00, 0x00, 0xff, 0x7f, 0x66, 0x7e, 0x66, 0x7e, 0x80, 0x3b, 0xf3, 0x7f, 0x20, 0x67, 0x68, 0x14],
    
    "Barbecue flavor": [0x00, 0x00, 0xde, 0x5f, 0x4c, 0x00, 0x06, 0x00, 0x45, 0x1a, 0xd3, 0x00, 0x4c, 0x00, 0x06, 0x00,
                        0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xd3, 0x00, 0x0c, 0x00, 0x06, 0x00,
                        0x80, 0x3b, 0xff, 0x7f, 0x0c, 0x00, 0x99, 0x01, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                        0x00, 0x00, 0x7f, 0x02, 0x4c, 0x00, 0x4c, 0x00, 0x80, 0x3b, 0xb0, 0x14, 0x4c, 0x00, 0x06, 0x00],

    "Lavender flavor": [0x00, 0x00, 0xde, 0x5f, 0x39, 0x7f, 0x25, 0x14, 0x45, 0x1a, 0xff, 0x77, 0x93, 0x3e, 0x25, 0x14,
                        0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x00, 0x00, 0xbf, 0x57, 0x79, 0x7e, 0x25, 0x14,
                        0x80, 0x3b, 0x86, 0x10, 0x39, 0x7f, 0x3f, 0x7f, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                        0x00, 0x00, 0xde, 0x5f, 0x73, 0x7e, 0x73, 0x7e, 0x80, 0x3b, 0x3f, 0x7f, 0x39, 0x7f, 0x25, 0x14],
    
    "Apple flavor": [0x00, 0x00, 0xde, 0x5f, 0x1F, 0x00, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0x6d, 0x3a, 0x25, 0x14,
                     0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                     0x80, 0x3b, 0xde, 0x5f, 0xdf, 0x18, 0x19, 0x00, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                     0x80, 0x3b, 0xde, 0x5f, 0x52, 0x79, 0x52, 0x79, 0x80, 0x3b, 0x3f, 0x67, 0xdf, 0x18, 0xc7, 0x28],

    "Orange flavor": [0x00, 0x00, 0xde, 0x5f, 0x9F, 0x01, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0x6d, 0x3a, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                      0x80, 0x3b, 0x0c, 0x00, 0x9f, 0x19, 0x7f, 0x1a, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0xde, 0x5f, 0x79, 0x02, 0x79, 0x02, 0x80, 0x3b, 0x3f, 0x67, 0xff, 0x2a, 0xc7, 0x28],

    "Toilet flavor": [0x00, 0x00, 0xde, 0x5f, 0xff, 0x7f, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x67, 0x93, 0x01, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                      0x80, 0x3b, 0x32, 0x01, 0x33, 0x7f, 0x66, 0x7e, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0x8c, 0x01, 0x3f, 0x1b, 0x3f, 0x1b, 0x80, 0x3b, 0xff, 0x7f, 0x9c, 0x7f, 0xc7, 0x28],

    "Peach flavor": [0x00, 0x00, 0xde, 0x5f, 0x3f, 0x1b, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x77, 0x6d, 0x3a, 0x25, 0x14,
                     0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                     0x80, 0x3b, 0xc6, 0x00, 0x7f, 0x32, 0x3f, 0x33, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                     0x80, 0x3b, 0xde, 0x5f, 0x52, 0x79, 0x52, 0x79, 0x80, 0x3b, 0x3f, 0x4f, 0x7f, 0x32, 0xc7, 0x28],

    "Bubblegum flavor": [0x00, 0x00, 0xde, 0x5f, 0x3f, 0x67, 0x25, 0x14, 0x80, 0x3b, 0x3f, 0x67, 0x7f, 0x7e, 0x25, 0x14,
                         0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xbf, 0x57, 0x4f, 0x79, 0x25, 0x14,
                         0x80, 0x3b, 0x86, 0x10, 0x3f, 0x7f, 0x79, 0x7e, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                         0x80, 0x3b, 0x86, 0x10, 0x9f, 0x65, 0x9f, 0x65, 0x80, 0x3b, 0x3f, 0x7f, 0x7f, 0x7e, 0xc7, 0x28],

    "Lemonade flavor": [0x00, 0x00, 0xde, 0x5f, 0x3f, 0x67, 0x25, 0x14, 0x80, 0x3b, 0xde, 0x63, 0x1e, 0x5f, 0x25, 0x14,
                             0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0x3f, 0x67, 0x4e, 0x7d, 0x25, 0x14,
                             0x80, 0x3b, 0xc6, 0x00, 0x1e, 0x5f, 0xff, 0x4f, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                             0x80, 0x3b, 0xde, 0x5f, 0x52, 0x79, 0x52, 0x79, 0x80, 0x3b, 0x9e, 0x5f, 0x1e, 0x5f, 0xc7, 0x28],

    "Garlic flavor": [0x00, 0x00, 0xff, 0x03, 0xff, 0x03, 0x25, 0x14, 0x80, 0x3b, 0xff, 0x33, 0x19, 0x64, 0x25, 0x14,
                      0x80, 0x3b, 0xde, 0x5f, 0xbf, 0x4c, 0xbf, 0x4c, 0x80, 0x3b, 0xff, 0x1b, 0x13, 0x4c, 0x25, 0x14,
                      0x80, 0x3b, 0xc6, 0x00, 0x79, 0x02, 0x3f, 0x1b, 0x80, 0x3b, 0xe7, 0x1c, 0xa5, 0x14, 0x42, 0x08,
                      0x80, 0x3b, 0xde, 0x5f, 0x13, 0x4c, 0x13, 0x4c, 0x80, 0x3b, 0xff, 0x33, 0x19, 0x64, 0xc7, 0x28]

}

vanilla_flavor_pointers = {
    "Mint flavor": [0x202008, 0x34B000, 0x34B110],
    "Strawberry flavor": [0x202048, 0x34B040, 0x34B112],
    "Banana flavor": [0x202088, 0x34B080, 0x34B114],
    "Peanut flavor": [0x2020C8, 0x34B0C0, 0x34B116]
}


def create_flavors(world: "EarthBoundWorld") -> None:
    """Shuffle flavors (textbox palettes). Vanilla flavors are copied from the ROM itself and not stored here."""
    world.flavor_text = []
    world.flavor_pointer = [0x01F72B, 0x01F746, 0x01F761, 0x01F77C]
    flavor_num = 0
    for flavor in world.available_flavors:
        encoded_flavor = []
        for char in flavor:
            encoded_flavor.extend(eb_text_table[char])
        encoded_flavor.extend([0x00])
        world.flavor_text.append(encoded_flavor)
        flavor_num += 1
